@@ -523,4 +523,7 @@ void gsr_egl_swap_buffers(gsr_egl *self) {
     self->glFlush();
     // TODO: Use the minimal barrier required
     self->glMemoryBarrier(GL_ALL_BARRIER_BITS); // GL_SHADER_IMAGE_ACCESS_BARRIER_BIT
+    // TODO: This is needed on nvidia because the cursor can flicker otherwise. Find a better solution
+    if(self->gpu_info.vendor == GSR_GPU_VENDOR_NVIDIA)
+        self->glFinish();
 }
